package cz.upol.zp4jv.lecture10;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.ResultSetMetaData;
import java.sql.SQLException;
import java.sql.Statement;

public class DatabaseClient {

	private static final String DB_NAME = "moviedb";
	private static final String HOST    = "localhost:1527";

	private Connection con;
	
	/**
	 * Pripoji se k DB pres sitove rozhrani
	 */
	public void connect() throws SQLException {
		String connectionURL = "jdbc:derby://" + HOST + "/" + DB_NAME;
		
		// vytvori pripojeni
		con = DriverManager.getConnection(connectionURL);
		System.out.println("Connecting to: " + connectionURL);
	}
	
	/** uzavre spojeni */ 
	public void close() throws SQLException {
		con.close();
	}
	
	/** vypise obsah tabulky "movies" */
	public void listMovies() throws SQLException {
		try (Statement stmt = con.createStatement()) {
		
			// prevede dotaz
			stmt.executeQuery("SELECT * FROM movies");
			
			// ziska data
			try (ResultSet results = stmt.getResultSet()) {
			
//				// je mozne ziskat i metadata 
//				ResultSetMetaData metaData = results.getMetaData();
//				
//				// sloupce
//				System.out.println("Pocet sloupcu: " + metaData.getColumnCount());
//				for (int i = 0; i < metaData.getColumnCount(); i++)
//					System.out.println(String.format("Sloupec #%1$s: %2$s\t(%3$s)", 
//							(i + 1), 
//							metaData.getColumnName(i + 1),
//							metaData.getColumnTypeName(i + 1)));
				
				
				while (results.next()) {
					String name     = results.getString(1); // sloupce jsou indexovany od jedne
					int releasedIn  = results.getInt(2);
					String director = results.getString("director"); // lze pristupovat i pres jmeno
					double rating   = results.getDouble("rating");
					System.out.println(name + ", " + director + ", " + releasedIn + ", " + rating);
				}
			}
		}
	}
	
// !!! toto je koncepcne spatne !!!
//	public void insertMovie(String name, int releasedIn, String director, double rating) throws SQLException {
//		try (Statement stmt = con.createStatement()) {
//			String query = "INSERT INTO movies (name, released_in, director, rating) VALUES ('" 
//					+ name + "', " + releasedIn + ", '" + director + "', " + rating + ")";
//			System.out.println("Query: " + query);
//			stmt.executeUpdate(query);
//		}
//	}
	
	public void insertMovie(String name, int releasedIn, String director, double rating) throws SQLException {
		String query = "INSERT INTO movies (name, released_in, director, rating) VALUES (?, ?, ?, ?)";
		try (PreparedStatement stmt = con.prepareStatement(query)) {
			stmt.setString(1, name);
			stmt.setInt(2, releasedIn);
			stmt.setString(3, director);
			stmt.setDouble(4, rating);
			stmt.executeUpdate();
		}
	}
	
	public static void main(String[] args) throws SQLException {
		DatabaseClient client = new DatabaseClient();
		client.connect();
//		client.insertMovie("The Simpsons Movie", 2007, "David Silverman", 7.3);
		client.insertMovie("A Bug's Life!", 1998, "John Lasseter", 7.2);
		client.listMovies();
		client.close();
	}

}
