package cz.upol.zp4jv.lecture10;

import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

public class EmbeddedDatabase {
	
	private static final String DB_NAME = "demodb";
	
	/**
	 * Vraci true pokud databazi existuje tabulka demo 
	 */
	private static boolean isReady(Connection con) throws SQLException {
		DatabaseMetaData dbm = con.getMetaData();
		try (ResultSet tables = dbm.getTables(null, null, "MOVIES", null)) {
			return tables.next();
		}
	}
	
	/**
	 * Vytvori a naplni tabulku (pouziva davkove zpracovani dat)
	 */
	private static void initializeTable(Connection con) throws SQLException {
		System.out.println("Vytvarim tabulku i s daty");
		try (Statement stmt = con.createStatement()) {
			stmt.addBatch("CREATE TABLE movies\n" + 
					"(name        varchar(50),\n" + 
					" released_in int,\n" + 
					" director    varchar(35),\n" + 
					" rating      double precision,\n" + 
					" PRIMARY KEY(name, released_in))");
			stmt.addBatch("INSERT INTO movies VALUES ('Forrest Gump', 1994, 'R. Zemeckis', 8.8)");
			stmt.addBatch("INSERT INTO movies (name, released_in, director, rating) VALUES ('Psycho', 1960, 'A. Hitchcock', 8.6)");
			stmt.executeBatch();
		}
	}

	public static void main(String[] args) throws SQLException, MovieDBException {
		String connectionURL = "jdbc:derby:" + DB_NAME + ";create=true";
		try (Connection con = DriverManager.getConnection(connectionURL)) {
			if (!isReady(con)) 
				initializeTable(con);
			
			try (MovieDatabase movies = new MovieDatabase(con)) {
				System.out.println(movies.getMovieNames());
			}
			
		}
	}
}
